@@ -9,7 +9,7 @@
     clippy::all
 )]
 
-use proc_macro2::TokenStream;
+use proc_macro2::{Group, Span, TokenStream, TokenTree};
 use quote::{quote, quote_spanned};
 use syn::{
     parse_macro_input, parse_quote, punctuated::Punctuated, spanned::Spanned, AttrStyle, Data,
@@ -29,6 +29,7 @@ struct Repr {
 struct Attributes {
     pub repr: Repr,
     pub bound: Option<LitStr>,
+    pub bytecheck_crate: Option<Path>,
 }
 
 fn parse_check_bytes_attributes(attributes: &mut Attributes, meta: &Meta) -> Result<(), Error> {
@@ -51,6 +52,25 @@ fn parse_check_bytes_attributes(attributes: &mut Attributes, meta: &Meta) -> Res
                         "bound arguments must be a string",
                     ))
                 }
+            } else if meta.path.is_ident("crate") {
+                if let Lit::Str(ref lit_str) = meta.lit {
+                    if attributes.bytecheck_crate.is_none() {
+                        let tokens = respan(syn::parse_str(&lit_str.value())?, lit_str.span());
+                        let parsed: Path = syn::parse2(tokens)?;
+                        attributes.bytecheck_crate = Some(parsed);
+                        Ok(())
+                    } else {
+                        Err(Error::new_spanned(
+                            meta,
+                            "check_bytes crate already specified",
+                        ))
+                    }
+                } else {
+                    Err(Error::new_spanned(
+                        &meta.lit,
+                        "crate argument must be a string",
+                    ))
+                }
             } else {
                 Err(Error::new_spanned(
                     &meta.path,
@@ -199,6 +219,7 @@ fn derive_check_bytes(mut input: DeriveInput) -> Result<TokenStream, Error> {
                 });
 
                 quote! {
+                    #[automatically_derived]
                     impl #impl_generics CheckBytes<__C> for #name #ty_generics #check_where {
                         type Error = StructCheckError;
 
@@ -241,6 +262,7 @@ fn derive_check_bytes(mut input: DeriveInput) -> Result<TokenStream, Error> {
                 });
 
                 quote! {
+                    #[automatically_derived]
                     impl #impl_generics CheckBytes<__C> for #name #ty_generics #check_where {
                         type Error = TupleStructCheckError;
 
@@ -257,6 +279,7 @@ fn derive_check_bytes(mut input: DeriveInput) -> Result<TokenStream, Error> {
             }
             Fields::Unit => {
                 quote! {
+                    #[automatically_derived]
                     impl #impl_generics CheckBytes<__C> for #name #ty_generics #impl_where_clause {
                         type Error = Infallible;
 
@@ -343,7 +366,7 @@ fn derive_check_bytes(mut input: DeriveInput) -> Result<TokenStream, Error> {
 
             let variant_structs = data.variants.iter().map(|v| {
                 let variant = &v.ident;
-                let variant_name = Ident::new(&format!("Variant{}", variant.to_string()), v.span());
+                let variant_name = Ident::new(&format!("Variant{variant}"), v.span());
                 match v.fields {
                     Fields::Named(ref fields) => {
                         let fields = fields.named.iter().map(|f| {
@@ -380,7 +403,7 @@ fn derive_check_bytes(mut input: DeriveInput) -> Result<TokenStream, Error> {
 
             let check_arms = data.variants.iter().map(|v| {
                 let variant = &v.ident;
-                let variant_name = Ident::new(&format!("Variant{}", variant.to_string()), v.span());
+                let variant_name = Ident::new(&format!("Variant{variant}"), v.span());
                 match v.fields {
                     Fields::Named(ref fields) => {
                         let checks = fields.named.iter().map(|f| {
@@ -438,12 +461,14 @@ fn derive_check_bytes(mut input: DeriveInput) -> Result<TokenStream, Error> {
 
                 struct Discriminant;
 
+                #[automatically_derived]
                 impl Discriminant {
                     #(#discriminant_const_defs)*
                 }
 
                 #(#variant_structs)*
 
+                #[automatically_derived]
                 impl #impl_generics CheckBytes<__C> for #name #ty_generics #check_where {
                     type Error = EnumCheckError<#repr>;
 
@@ -469,10 +494,17 @@ fn derive_check_bytes(mut input: DeriveInput) -> Result<TokenStream, Error> {
         }
     };
 
+    // Default to `bytecheck`, rather than `::bytecheck`,
+    // to allow providing it from a reexport, e.g. `use rkyv::bytecheck;`.
+    let bytecheck_crate = attributes
+        .bytecheck_crate
+        .unwrap_or(parse_quote!(bytecheck));
+
     Ok(quote! {
+        #[allow(unused_results)]
         const _: () = {
             use ::core::{convert::Infallible, marker::PhantomData};
-            use bytecheck::{
+            use #bytecheck_crate::{
                 CheckBytes,
                 EnumCheckError,
                 ErrorBox,
@@ -484,3 +516,18 @@ fn derive_check_bytes(mut input: DeriveInput) -> Result<TokenStream, Error> {
         };
     })
 }
+
+fn respan(stream: TokenStream, span: Span) -> TokenStream {
+    stream
+        .into_iter()
+        .map(|token| respan_token(token, span))
+        .collect()
+}
+
+fn respan_token(mut token: TokenTree, span: Span) -> TokenTree {
+    if let TokenTree::Group(g) = &mut token {
+        *g = Group::new(g.delimiter(), respan(g.stream(), span));
+    }
+    token.set_span(span);
+    token
+}
